Documentation
¶
Index ¶
- Constants
- func DialogStatusCmd(message DialogStatusMsg) tea.Cmd
- func HelpDialog(entries ...HelpEntry) tea.Model
- func New(message string, cancelOnly bool, standalone bool, width int) tea.Model
- func NewConfirmDialog(message string, width int) tea.Model
- func NewOKDialog(message string, width int) tea.Model
- func NewStanaloneOKDialog(message string, width int) tea.Model
- func NewStandaloneConfirmDialog(message string, width int) tea.Model
- type Dialog
- type DialogStatusMsg
- type HelpEntry
- type Status
- type UseHelp
Constants ¶
const DialogHeight = 15
Variables ¶
This section is empty.
Functions ¶
func DialogStatusCmd ¶
func DialogStatusCmd(message DialogStatusMsg) tea.Cmd
func HelpDialog ¶
func NewConfirmDialog ¶
Creates a new confirmation dialog
This is a convenience method to create a confirmation dialog containing both yes and no buttons
func NewOKDialog ¶
Creates a new OK dialog
This is a convenience method to create a confirmation dialog that only has an OK button
func NewStanaloneOKDialog ¶
Create a new OK dialog
For standalone applications only ¶
This is a convenience method for creating an OK dialog that runs inside a TMUX popup window.
This method should not be used from inside the main window. Use NewOKDialog for that
func NewStandaloneConfirmDialog ¶
Create a new standalone confirmation dialog
For standalone applications only ¶
This is a convenience method for creating dialogs that run inside a TMUX popup window.
This method should not be used from inside the main window. Use NewConfirmDialog for that
Types ¶
type Dialog ¶
type Dialog struct {
// contains filtered or unexported fields
}
func (*Dialog) Overlay ¶
func (m *Dialog) Overlay() helpers.UseOverlay
type DialogStatusMsg ¶
Click to show internal directories.
Click to hide internal directories.