Documentation
¶
Index ¶
Constants ¶
const ( MinHeight = 30 MinWidth = 110 DialogWidth = 30 )
const ( DefaultDarkTheme = "tokyo_night" DefaultLightTheme = "tokyo_night_day" )
Variables ¶
This section is empty.
Functions ¶
func NewConfigModel ¶
func NewConfigModel(c *Config) *configModel
Create a new configuration UI model
The config UI is there to help guide users through the process of creating and managing the UI config.
Although the primary config is fairly basic, this helps guide users in its creation.
Types ¶
type Config ¶
type Config struct {
Paths []string `yaml:"paths"`
CreateSessionKubeConfig bool `yaml:"createSessionKubeConfig"`
DefaultSession string `yaml:"defaultSession"`
ManageSessionKubeContext bool `yaml:"manageSessionKubeContext"`
Theme string `yaml:"theme"`
Sessions []helpers.Session `yaml:"sessions"`
// contains filtered or unexported fields
}
func New ¶
Create a new config object
This will create a new Config object and load the config from disk If the configuration can't be found, a UI will be shown to help create the config. This is then stored at `~/.config/{appname}/config.yaml`
func (*Config) GetConfigFile ¶
Get the name of the config file being used
This returns a full path to the config file on disk
func (*Config) SetDefaultSession ¶
Set the default session
Click to show internal directories.
Click to hide internal directories.