Documentation
¶
Index ¶
- func ExecString() string
- func ExecutableName() string
- func NewErrorCmd(err error) tea.Cmd
- func OverlayCmd(message any) tea.Cmd
- func ReloadManagerCmd() tea.Cmd
- func ReloadWindowsCmd() tea.Cmd
- func SaveSessionsCmd() tea.Cmd
- type ErrorMsg
- type OverlayMsg
- type Pane
- type ReloadManagerMsg
- type ReloadWindowsMsg
- type SaveMsg
- type Session
- type UseOverlay
- type Window
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecString ¶
func ExecString() string
ExecString is primarily used for popups which by default start in the users home directory.
This method is used to run popupe in the current terminal directory
func ExecutableName ¶
func ExecutableName() string
ExecutableName gets the name of the current running program
func NewErrorCmd ¶
NewErrorCmd is returned by components that are in error
func OverlayCmd ¶
OverlayCmd is the tea command being returned from an overlay
func ReloadManagerCmd ¶
ReloadManagerCmd is the tea command to trigger a ReloadManagerMsg
func ReloadWindowsCmd ¶
ReloadWindowsCmd triggers the sending of a ReloadWindowsMsg
func SaveSessionsCmd ¶
SaveSessionsCmd sends the message that sessions should be saved to config
Types ¶
type ErrorMsg ¶
type ErrorMsg struct {
Error error
}
ErrorMsg is a tea message used to instruct the program it is in an error state
type OverlayMsg ¶
type OverlayMsg struct {
Message any
}
OverlayMsg is a tea message that contains information from an overlay window
type Pane ¶
type Pane struct {
CurrentCommand string `yaml:"pane_current_command"`
CurrentPath string `yaml:"pane_current_path"`
StartCommand string `yaml:"pane_start_command"`
StartPath string `yaml:"pane_start_path"`
Title string `yaml:"title"`
}
Pane is a light wrapper for a pane within a window
type ReloadManagerMsg ¶
type ReloadManagerMsg struct{}
ReloadManagerMsg instructs the session manager that it needs to reload components
type ReloadWindowsMsg ¶
type ReloadWindowsMsg struct{}
ReloadWindowsMsg triggers the relaoding of session windows
type Session ¶
type Session struct {
Command string `yaml:"command"`
Name string `yaml:"name"`
Path string `yaml:"path"`
Windows []Window `yaml:"windows"`
}
Session is a light wrapper for a tmux session